Class: Google::Cloud::Speech::V2::CustomPromptConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/speech/v2/cloud_speech.rb

Overview

Configuration to enable custom prompt in chirp3.

Instance Attribute Summary collapse

Instance Attribute Details

#custom_prompt::String

Returns Optional. The custom instructions to override the existing instructions for chirp3.

Returns:

  • (::String)

    Optional. The custom instructions to override the existing instructions for chirp3.



515
516
517
518
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 515

class CustomPromptConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end