Class: Google::Cloud::Speech::V2::ListPhraseSetsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Speech::V2::ListPhraseSetsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/speech/v2/cloud_speech.rb
Overview
Request message for the ListPhraseSets method.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
The maximum number of PhraseSets to return.
-
#page_token ⇒ ::String
A page token, received from a previous ListPhraseSets call.
-
#parent ⇒ ::String
Required.
-
#show_deleted ⇒ ::Boolean
Whether, or not, to show resources that have been deleted.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns The maximum number of PhraseSets to return. The service may return fewer than this value. If unspecified, at most 5 PhraseSets will be returned. The maximum value is 100; values above 100 will be coerced to 100.
1986 1987 1988 1989 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1986 class ListPhraseSetsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns A page token, received from a previous ListPhraseSets call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListPhraseSets must match the call that provided the page token.
1986 1987 1988 1989 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1986 class ListPhraseSetsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The project and location of PhraseSet resources to list. The
expected format is projects/{project}/locations/{location}.
1986 1987 1988 1989 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1986 class ListPhraseSetsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#show_deleted ⇒ ::Boolean
Returns Whether, or not, to show resources that have been deleted.
1986 1987 1988 1989 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1986 class ListPhraseSetsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |