Class: Google::Cloud::Speech::V2::RecognitionFeatures

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/speech/v2/cloud_speech.rb

Overview

Available recognition features.

Defined Under Namespace

Modules: MultiChannelMode

Instance Attribute Summary collapse

Instance Attribute Details

#custom_prompt_config::Google::Cloud::Speech::V2::CustomPromptConfig

Returns Optional. Configuration to enable custom prompt for chirp3.

Returns:



571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 571

class RecognitionFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for how to recognize multi-channel audio.
  module MultiChannelMode
    # Default value for the multi-channel mode. If the audio contains
    # multiple channels, only the first channel will be transcribed; other
    # channels will be ignored.
    MULTI_CHANNEL_MODE_UNSPECIFIED = 0

    # If selected, each channel in the provided audio is transcribed
    # independently. This cannot be selected if the selected
    # {::Google::Cloud::Speech::V2::Recognizer#model model} is `latest_short`.
    SEPARATE_RECOGNITION_PER_CHANNEL = 1
  end
end

#diarization_config::Google::Cloud::Speech::V2::SpeakerDiarizationConfig

Returns Configuration to enable speaker diarization. To enable diarization, set this field to an empty SpeakerDiarizationConfig message.

Returns:



571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 571

class RecognitionFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for how to recognize multi-channel audio.
  module MultiChannelMode
    # Default value for the multi-channel mode. If the audio contains
    # multiple channels, only the first channel will be transcribed; other
    # channels will be ignored.
    MULTI_CHANNEL_MODE_UNSPECIFIED = 0

    # If selected, each channel in the provided audio is transcribed
    # independently. This cannot be selected if the selected
    # {::Google::Cloud::Speech::V2::Recognizer#model model} is `latest_short`.
    SEPARATE_RECOGNITION_PER_CHANNEL = 1
  end
end

#enable_automatic_punctuation::Boolean

Returns If true, adds punctuation to recognition result hypotheses. This feature is only available in select languages. The default false value does not add punctuation to result hypotheses.

Returns:

  • (::Boolean)

    If true, adds punctuation to recognition result hypotheses. This feature is only available in select languages. The default false value does not add punctuation to result hypotheses.



571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 571

class RecognitionFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for how to recognize multi-channel audio.
  module MultiChannelMode
    # Default value for the multi-channel mode. If the audio contains
    # multiple channels, only the first channel will be transcribed; other
    # channels will be ignored.
    MULTI_CHANNEL_MODE_UNSPECIFIED = 0

    # If selected, each channel in the provided audio is transcribed
    # independently. This cannot be selected if the selected
    # {::Google::Cloud::Speech::V2::Recognizer#model model} is `latest_short`.
    SEPARATE_RECOGNITION_PER_CHANNEL = 1
  end
end

#enable_spoken_emojis::Boolean

Returns The spoken emoji behavior for the call. If true, adds spoken emoji formatting for the request. This will replace spoken emojis with the corresponding Unicode symbols in the final transcript. If false, spoken emojis are not replaced.

Returns:

  • (::Boolean)

    The spoken emoji behavior for the call. If true, adds spoken emoji formatting for the request. This will replace spoken emojis with the corresponding Unicode symbols in the final transcript. If false, spoken emojis are not replaced.



571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 571

class RecognitionFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for how to recognize multi-channel audio.
  module MultiChannelMode
    # Default value for the multi-channel mode. If the audio contains
    # multiple channels, only the first channel will be transcribed; other
    # channels will be ignored.
    MULTI_CHANNEL_MODE_UNSPECIFIED = 0

    # If selected, each channel in the provided audio is transcribed
    # independently. This cannot be selected if the selected
    # {::Google::Cloud::Speech::V2::Recognizer#model model} is `latest_short`.
    SEPARATE_RECOGNITION_PER_CHANNEL = 1
  end
end

#enable_spoken_punctuation::Boolean

Returns The spoken punctuation behavior for the call. If true, replaces spoken punctuation with the corresponding symbols in the request. For example, "how are you question mark" becomes "how are you?". See https://cloud.google.com/speech-to-text/docs/spoken-punctuation for support. If false, spoken punctuation is not replaced.

Returns:

  • (::Boolean)

    The spoken punctuation behavior for the call. If true, replaces spoken punctuation with the corresponding symbols in the request. For example, "how are you question mark" becomes "how are you?". See https://cloud.google.com/speech-to-text/docs/spoken-punctuation for support. If false, spoken punctuation is not replaced.



571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 571

class RecognitionFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for how to recognize multi-channel audio.
  module MultiChannelMode
    # Default value for the multi-channel mode. If the audio contains
    # multiple channels, only the first channel will be transcribed; other
    # channels will be ignored.
    MULTI_CHANNEL_MODE_UNSPECIFIED = 0

    # If selected, each channel in the provided audio is transcribed
    # independently. This cannot be selected if the selected
    # {::Google::Cloud::Speech::V2::Recognizer#model model} is `latest_short`.
    SEPARATE_RECOGNITION_PER_CHANNEL = 1
  end
end

#enable_word_confidence::Boolean

Returns If true, the top result includes a list of words and the confidence for those words. If false, no word-level confidence information is returned. The default is false.

Returns:

  • (::Boolean)

    If true, the top result includes a list of words and the confidence for those words. If false, no word-level confidence information is returned. The default is false.



571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 571

class RecognitionFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for how to recognize multi-channel audio.
  module MultiChannelMode
    # Default value for the multi-channel mode. If the audio contains
    # multiple channels, only the first channel will be transcribed; other
    # channels will be ignored.
    MULTI_CHANNEL_MODE_UNSPECIFIED = 0

    # If selected, each channel in the provided audio is transcribed
    # independently. This cannot be selected if the selected
    # {::Google::Cloud::Speech::V2::Recognizer#model model} is `latest_short`.
    SEPARATE_RECOGNITION_PER_CHANNEL = 1
  end
end

#enable_word_time_offsets::Boolean

Returns If true, the top result includes a list of words and the start and end time offsets (timestamps) for those words. If false, no word-level time offset information is returned. The default is false.

Returns:

  • (::Boolean)

    If true, the top result includes a list of words and the start and end time offsets (timestamps) for those words. If false, no word-level time offset information is returned. The default is false.



571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 571

class RecognitionFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for how to recognize multi-channel audio.
  module MultiChannelMode
    # Default value for the multi-channel mode. If the audio contains
    # multiple channels, only the first channel will be transcribed; other
    # channels will be ignored.
    MULTI_CHANNEL_MODE_UNSPECIFIED = 0

    # If selected, each channel in the provided audio is transcribed
    # independently. This cannot be selected if the selected
    # {::Google::Cloud::Speech::V2::Recognizer#model model} is `latest_short`.
    SEPARATE_RECOGNITION_PER_CHANNEL = 1
  end
end

#max_alternatives::Integer

Returns Maximum number of recognition hypotheses to be returned. The server may return fewer than max_alternatives. Valid values are 0-30. A value of 0 or 1 will return a maximum of one. If omitted, will return a maximum of one.

Returns:

  • (::Integer)

    Maximum number of recognition hypotheses to be returned. The server may return fewer than max_alternatives. Valid values are 0-30. A value of 0 or 1 will return a maximum of one. If omitted, will return a maximum of one.



571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 571

class RecognitionFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for how to recognize multi-channel audio.
  module MultiChannelMode
    # Default value for the multi-channel mode. If the audio contains
    # multiple channels, only the first channel will be transcribed; other
    # channels will be ignored.
    MULTI_CHANNEL_MODE_UNSPECIFIED = 0

    # If selected, each channel in the provided audio is transcribed
    # independently. This cannot be selected if the selected
    # {::Google::Cloud::Speech::V2::Recognizer#model model} is `latest_short`.
    SEPARATE_RECOGNITION_PER_CHANNEL = 1
  end
end

#multi_channel_mode::Google::Cloud::Speech::V2::RecognitionFeatures::MultiChannelMode

Returns Mode for recognizing multi-channel audio.

Returns:



571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 571

class RecognitionFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for how to recognize multi-channel audio.
  module MultiChannelMode
    # Default value for the multi-channel mode. If the audio contains
    # multiple channels, only the first channel will be transcribed; other
    # channels will be ignored.
    MULTI_CHANNEL_MODE_UNSPECIFIED = 0

    # If selected, each channel in the provided audio is transcribed
    # independently. This cannot be selected if the selected
    # {::Google::Cloud::Speech::V2::Recognizer#model model} is `latest_short`.
    SEPARATE_RECOGNITION_PER_CHANNEL = 1
  end
end

#profanity_filter::Boolean

Returns If set to true, the server will attempt to filter out profanities, replacing all but the initial character in each filtered word with asterisks, for instance, "f***". If set to false or omitted, profanities won't be filtered out.

Returns:

  • (::Boolean)

    If set to true, the server will attempt to filter out profanities, replacing all but the initial character in each filtered word with asterisks, for instance, "f***". If set to false or omitted, profanities won't be filtered out.



571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 571

class RecognitionFeatures
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Options for how to recognize multi-channel audio.
  module MultiChannelMode
    # Default value for the multi-channel mode. If the audio contains
    # multiple channels, only the first channel will be transcribed; other
    # channels will be ignored.
    MULTI_CHANNEL_MODE_UNSPECIFIED = 0

    # If selected, each channel in the provided audio is transcribed
    # independently. This cannot be selected if the selected
    # {::Google::Cloud::Speech::V2::Recognizer#model model} is `latest_short`.
    SEPARATE_RECOGNITION_PER_CHANNEL = 1
  end
end