Class: Google::Cloud::Speech::V2::SpeechAdaptation
- Inherits:
-
Object
- Object
- Google::Cloud::Speech::V2::SpeechAdaptation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/speech/v2/cloud_speech.rb
Overview
Provides "hints" to the speech recognizer to favor specific words and phrases in the results. PhraseSets can be specified as an inline resource, or a reference to an existing PhraseSet resource.
Defined Under Namespace
Classes: AdaptationPhraseSet
Instance Attribute Summary collapse
-
#custom_classes ⇒ ::Array<::Google::Cloud::Speech::V2::CustomClass>
A list of inline CustomClasses.
-
#phrase_sets ⇒ ::Array<::Google::Cloud::Speech::V2::SpeechAdaptation::AdaptationPhraseSet>
A list of inline or referenced PhraseSets.
Instance Attribute Details
#custom_classes ⇒ ::Array<::Google::Cloud::Speech::V2::CustomClass>
Returns A list of inline CustomClasses. Existing CustomClass resources can be referenced directly in a PhraseSet.
639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 639 class SpeechAdaptation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A biasing PhraseSet, which can be either a string referencing the name of # an existing PhraseSets resource, or an inline definition of a PhraseSet. # @!attribute [rw] phrase_set # @return [::String] # The name of an existing PhraseSet resource. The user must have read # access to the resource and it must not be deleted. # # Note: The following fields are mutually exclusive: `phrase_set`, `inline_phrase_set`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] inline_phrase_set # @return [::Google::Cloud::Speech::V2::PhraseSet] # An inline defined PhraseSet. # # Note: The following fields are mutually exclusive: `inline_phrase_set`, `phrase_set`. If a field in that set is populated, all other fields in the set will automatically be cleared. class AdaptationPhraseSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#phrase_sets ⇒ ::Array<::Google::Cloud::Speech::V2::SpeechAdaptation::AdaptationPhraseSet>
Returns A list of inline or referenced PhraseSets.
639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 639 class SpeechAdaptation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A biasing PhraseSet, which can be either a string referencing the name of # an existing PhraseSets resource, or an inline definition of a PhraseSet. # @!attribute [rw] phrase_set # @return [::String] # The name of an existing PhraseSet resource. The user must have read # access to the resource and it must not be deleted. # # Note: The following fields are mutually exclusive: `phrase_set`, `inline_phrase_set`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] inline_phrase_set # @return [::Google::Cloud::Speech::V2::PhraseSet] # An inline defined PhraseSet. # # Note: The following fields are mutually exclusive: `inline_phrase_set`, `phrase_set`. If a field in that set is populated, all other fields in the set will automatically be cleared. class AdaptationPhraseSet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |