Module: Google::Cloud::Speech::V2::StreamingRecognitionFeatures::EndpointingSensitivity

Defined in:
proto_docs/google/cloud/speech/v2/cloud_speech.rb

Overview

Endpointing sensitivity is intended for applications that want to minimize result latency, possibly at the expense of quality. Some utterances may be broken up into multiple fragments.

Constant Summary collapse

ENDPOINTING_SENSITIVITY_UNSPECIFIED =

If no value is specified, the values for ENDPOINTING_SENSITIVITY_STANDARD will be used.

0
ENDPOINTING_SENSITIVITY_STANDARD =

Standard sensitivity, no optimization for latency.

1
ENDPOINTING_SENSITIVITY_SUPERSHORT =

Super short sensitivity, optimized for super short utterances like single words ("Yes", "No", "Hello", etc.) or a single phrase, command or short query (e.g. "check balance", "five dollars", "call Mom").

2
ENDPOINTING_SENSITIVITY_SHORT =

Short sensitivity, optimized for short utterances like single sentences. (e.g. "Remind me to call the dentist tomorrow morning at nine", "Navigate to the nearest coffee shop that is currently open")

3