Class: Google::Cloud::Speech::V2::CustomClass
- Inherits:
-
Object
- Object
- Google::Cloud::Speech::V2::CustomClass
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/speech/v2/cloud_speech.rb
Overview
CustomClass for biasing in speech recognition. Used to define a set of words or phrases that represents a common concept or theme likely to appear in your audio, for example a list of passenger ship names.
Defined Under Namespace
Modules: State Classes: AnnotationsEntry, ClassItem
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#delete_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Optional.
-
#etag ⇒ ::String
readonly
Output only.
-
#expire_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#items ⇒ ::Array<::Google::Cloud::Speech::V2::CustomClass::ClassItem>
A collection of class items.
-
#kms_key_name ⇒ ::String
readonly
Output only.
-
#kms_key_version_name ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#reconciling ⇒ ::Boolean
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Speech::V2::CustomClass::State
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Allows users to store small amounts of arbitrary data. Both the key and the value must be 63 characters or less each. At most 100 annotations.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Creation time.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#delete_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which this resource was requested for deletion.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#display_name ⇒ ::String
Returns Optional. User-settable, human-readable name for the CustomClass. Must be 63 characters or less.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#etag ⇒ ::String (readonly)
Returns Output only. This checksum is computed by the server based on the value of other fields. This may be sent on update, undelete, and delete requests to ensure the client has an up-to-date value before proceeding.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#expire_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which this resource will be purged.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#items ⇒ ::Array<::Google::Cloud::Speech::V2::CustomClass::ClassItem>
Returns A collection of class items.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#kms_key_name ⇒ ::String (readonly)
Returns Output only. The KMS key
name with which
the CustomClass is encrypted. The expected format is
projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#kms_key_version_name ⇒ ::String (readonly)
Returns Output only. The KMS key version
name
with which the CustomClass is encrypted. The expected format is
projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}/cryptoKeyVersions/{crypto_key_version}.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#name ⇒ ::String (readonly)
Returns Output only. Identifier. The resource name of the CustomClass.
Format:
projects/{project}/locations/{location}/customClasses/{custom_class}.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#reconciling ⇒ ::Boolean (readonly)
Returns Output only. Whether or not this CustomClass is in the process of being updated.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#state ⇒ ::Google::Cloud::Speech::V2::CustomClass::State (readonly)
Returns Output only. The CustomClass lifecycle state.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#uid ⇒ ::String (readonly)
Returns Output only. System-assigned unique identifier for the CustomClass.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The most recent time this resource was modified.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1631 class CustomClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An item of the class. # @!attribute [rw] value # @return [::String] # The class item's value. class ClassItem include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Set of states that define the lifecycle of a CustomClass. module State # Unspecified state. This is only used/useful for distinguishing # unset values. STATE_UNSPECIFIED = 0 # The normal and active state. ACTIVE = 2 # This CustomClass has been deleted. DELETED = 4 end end |