Class: Google::Cloud::Speech::V2::DenoiserConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Speech::V2::DenoiserConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/speech/v2/cloud_speech.rb
Overview
Denoiser config. May not be supported for all models and may have no effect.
Instance Attribute Summary collapse
-
#denoise_audio ⇒ ::Boolean
Denoise audio before sending to the transcription model.
-
#snr_threshold ⇒ ::Float
Signal-to-Noise Ratio (SNR) threshold for the denoiser.
Instance Attribute Details
#denoise_audio ⇒ ::Boolean
Returns Denoise audio before sending to the transcription model.
675 676 677 678 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 675 class DenoiserConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#snr_threshold ⇒ ::Float
Returns Signal-to-Noise Ratio (SNR) threshold for the denoiser. Here SNR means the loudness of the speech signal. Audio with an SNR below this threshold, meaning the speech is too quiet, will be prevented from being sent to the transcription model.
If snr_threshold=0, no filtering will be applied.
675 676 677 678 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 675 class DenoiserConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |