Class: Google::Cloud::Speech::V2::RecognitionOutputConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Speech::V2::RecognitionOutputConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/speech/v2/cloud_speech.rb
Overview
Configuration options for the output(s) of recognition.
Instance Attribute Summary collapse
-
#gcs_output_config ⇒ ::Google::Cloud::Speech::V2::GcsOutputConfig
If this message is populated, recognition results are written to the provided Google Cloud Storage URI.
-
#inline_response_config ⇒ ::Google::Cloud::Speech::V2::InlineOutputConfig
If this message is populated, recognition results are provided in the BatchRecognizeResponse message of the Operation when completed.
-
#output_format_config ⇒ ::Google::Cloud::Speech::V2::OutputFormatConfig
Optional.
Instance Attribute Details
#gcs_output_config ⇒ ::Google::Cloud::Speech::V2::GcsOutputConfig
Returns If this message is populated, recognition results are written to the provided Google Cloud Storage URI.
Note: The following fields are mutually exclusive: gcs_output_config, inline_response_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
1198 1199 1200 1201 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1198 class RecognitionOutputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#inline_response_config ⇒ ::Google::Cloud::Speech::V2::InlineOutputConfig
Returns If this message is populated, recognition results are provided in the BatchRecognizeResponse message of the Operation when completed. This is only supported when calling BatchRecognize with just one audio file.
Note: The following fields are mutually exclusive: inline_response_config, gcs_output_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
1198 1199 1200 1201 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1198 class RecognitionOutputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_format_config ⇒ ::Google::Cloud::Speech::V2::OutputFormatConfig
Returns Optional. Configuration for the format of the results stored to output.
If unspecified transcripts will be written in the NATIVE format only.
1198 1199 1200 1201 |
# File 'proto_docs/google/cloud/speech/v2/cloud_speech.rb', line 1198 class RecognitionOutputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |